*************************************************************************
* Copyright 2010, Pericom Semiconductor Corporation			* 
* All Rights Reserved							*
* CONFIDENTIAL INFORMATION - 						*
* Pericom Semiconductor Corporation PROPRIETARY				*
*************************************************************************

* PI3EQX6741ST REDRIVER SIMULATION.
* TX -- differential signal input;
* RX -- differential output signal after redriver
* for all control settings, please refer to the datasheet; 

* Redriver diff. inputs at VIP & VIN
* Redriver diff. outputs at VOP & VON


.temp 90

*************************************************************************
* Simulation options and Library					*
*************************************************************************
.option post probe runlvl=6 method=gear
.option gshdc=1e-12


* Simulation Models
.inc 'header'

*************************************************************************
* Power Supplies and Controls						*
*************************************************************************
.param power3p3 = 3.3
vavdd	vdd3p3 0	power3p3
vagnd	agnd 0		0

***********************************************
$ Rate Detector setting
$ the pin is NOT AVAILABLE in silicon
$ It forces the result of rate detector
$ to bypass rate detector evatuation only
$ Datarate      hdrv
$ 3Gbps         0
$ 6Gbps         power
***********************************************
.param hdrv=power3p3
vhdr    hdr 0   hdrv


********************************
* PD pin
*	Status		pd
*       Active		0
*	Powerdown		1
********************************
vpd	pd 0		0

********************************
* Pre-emphasis settings
* Measured at 6Gbps signal
* Pre-emphasis		pea
* 	+0dB		0
* 	+1.5dB		1

* Measured at 3Gbps signal
* Pre-emphasis          pea
*       +0dB            0
*       +3dB          1
********************************
.param pev=0
vp0	pea 0		pev

********************************
* Equalizer settings
* Measured at 6Gbps signal
*	EQ		eqa
*       3.16dB		0
*       6.23dB		HIZ
*       9.34dB		1
********************************
req0	eqa 0		1m


***********************************************
$ Rate Detector setting
$ the pin is NOT AVAILABLE in silison
$ for simulation purpose only
$ Datarate	hdrv
$ 3Gbps		0
$ 6Gbps		power
***********************************************
.param hdrv=power3p3
vhdr	hdr 0	hdrv


*************************************************************************
* Diffential Signal Input, compliance pattern				*
*************************************************************************
.inc 'prbs7.inc'
rfil	in inx	10
cfil	inx 0	1.5p

ginp	0 tpp1	inx 0	'0.5/50' 
ginn	0 tpn1	inx 0	'-0.5/50'

rsrcp	tpp1 0		50
rsrcn	tpn1 0		50

*************************************************************************
* Input channel T-line; length = 4 inches                              *
*************************************************************************
wlp1 N=1 tpp1 0 tpp2 0 fgd=8500meg RLGCmodel=model1_tl8 L='4*25.4mm'
wln1 N=1 tpn1 0 tpn2 0 fgd=8500meg RLGCmodel=model1_tl8 L='4*25.4mm'

*************************************************************************
* External Input AC coupling                                            *
*************************************************************************
crxp    tpp2 vip	4.7n
crxn    tpn2 vin	4.7n

*************************************************************************
* Redriver PI3EQX6741ST							*
* netlist.up calls subckt Redriver					*
*************************************************************************
.inc 'netlist.up'

*************************************************************************
* Output AC coupling							*
*************************************************************************
ctxp	vop tpp3	4.7n
ctxn	von tpn3	4.7n

*************************************************************************
* Output channel T-line; length = 4 inches                              *
*************************************************************************
wlp2 N=1 tpp3 0 outp 0 fgd=8500meg RLGCmodel=model1_tl8 L='4*25.4mm'
wln2 N=1 tpn3 0 outn 0 fgd=8500meg RLGCmodel=model1_tl8 L='4*25.4mm'

*************************************************************************
* Load at Receiver							*
*************************************************************************
rpp	outp 0		50
rnn	outn 0		50

*************************************************************************
* Simulation Commands and Probe						*
*************************************************************************
.param tstart=100n tdelay='tstart-5n' tstop='tstart+128*per2' 
.param datarate=6g per2='1/datarate' dtr=100p dtf=100p amp=600m

.tran	100p 'tstart' 'per2/100' 'tstop' start='tstart'

.probe tran ax = par('time-int(time/per2)*per2')

.probe v(tpp1) v(tpn1)	TX=v(tpp1 tpn1)
.probe v(tpp2) v(tpn2)	TP2=v(tpp2 tpn2)

.probe v(vip) v(vin)	redrv_in=v(vip vin) 
.probe v(vop) v(von)	redrv_out=v(vop von)

.probe v(tpp3) v(tpn3)	TP3=v(tpp3 tpn3)
.probe v(outp) v(outn) 	RX=v(outp outn)

.end


